pub struct DisplayTemplate<'s> {
pub state: TemplateState<'s>,
pub id: String,
pub filename: String,
pub expiry_date: Option<DateTime<Utc>>,
pub expiry_relative: Option<TimeDelta>,
pub size: u64,
pub mimetype: Mime,
pub contents: DisplayType,
pub raw_url: Url,
pub download_url: Url,
}Fields
state: TemplateState<'s>id: Stringfilename: Stringexpiry_date: Option<DateTime<Utc>>expiry_relative: Option<TimeDelta>size: u64mimetype: Mimecontents: DisplayTyperaw_url: Urldownload_url: UrlTrait Implementations
Sourceimpl<'s> Display for DisplayTemplate<'s>
Implement the format!() trait for DisplayTemplate
impl<'s> Display for DisplayTemplate<'s>
Implement the format!() trait for DisplayTemplate
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl<'s> FastWritable for DisplayTemplate<'s>
impl<'s> FastWritable for DisplayTemplate<'s>
Sourceimpl<'s> Template for DisplayTemplate<'s>
impl<'s> Template for DisplayTemplate<'s>
Sourceconst SIZE_HINT: usize = 3964usize
const SIZE_HINT: usize = 3964usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl<'s> Freeze for DisplayTemplate<'s>
impl<'s> RefUnwindSafe for DisplayTemplate<'s>
impl<'s> Send for DisplayTemplate<'s>
impl<'s> Sync for DisplayTemplate<'s>
impl<'s> Unpin for DisplayTemplate<'s>
impl<'s> UnsafeUnpin for DisplayTemplate<'s>
impl<'s> UnwindSafe for DisplayTemplate<'s>